@@ -34,6 +34,7 @@ from .geno_tools import (
     check_beta_column,
     check_p_column,
     fill_se_p,
+    fill_fstatistic,
     check_allele_column,
     check_snp_column,
     remove_na,
@@ -145,15 +146,9 @@ class Geno:
         # List to keep track of checks performed
         self.checks = CHECKS_DICT.copy()
 
-        # Set the maximal amount of ram/cpu to be used by the methods and dask chunksize
-        self.cpus = int(os.environ.get("SLURM_CPUS_PER_TASK", default=os.cpu_count())) - 1
-        non_hpc_ram_per_cpu = psutil.virtual_memory().total  / (
-            1024**2 * self.cpus
-        )
-        ram_per_cpu = int(
-            os.environ.get("SLURM_MEM_PER_CPU", default=non_hpc_ram_per_cpu)
-        )
-        self.ram = int(ram_per_cpu * self.cpus * 0.8)
+        # Set the maximal amount of ram/cpu to be used by the methods
+        self.cpus = os.cpu_count() - 1
+        self.ram = int(psutil.virtual_memory().total / 1024**2 * 0.8)
 
         create_tmp()
 
@@ -168,6 +163,7 @@ class Geno:
         keep_dups=None,
         fill_snpids=None,
         fill_coordinates=None,
+        fill_f=False,
     ):
         """
         Clean and preprocess the main dataframe of Single Nucleotide Polymorphisms (SNP) data.
@@ -187,6 +183,9 @@ class Geno:
             keep_dups (bool, optional): Determines if rows with duplicate SNP IDs should be kept. If None, defers to preprocessing value. Defaults to None.
             fill_snpids (bool, optional): Decides if the SNP (rsID) column should be created or replaced based on CHR/POS columns and a reference genome. If None, defers to preprocessing value. Defaults to None.
             fill_coordinates (bool, optional): Decides if CHR and/or POS should be created or replaced based on SNP column and a reference genome. If None, defers to preprocessing value. Defaults to None.
+            fill_f (bool, optional): If True, force recomputation/overwrite of the FSTAT column even if it 
+                already exists. If False (default), FSTAT is created if missing, or only missing values 
+                are filled if the column already exists.
 
         Note:
             If you pass a standard reference_panel name (e.g. "EUR_37"), it will be converted to "37".
@@ -256,8 +255,8 @@ class Geno:
             data = fill_ea_nea(data, self.get_reference_panel(reference_panel))
 
         # Convert effect column to Beta estimates if present
-        if "BETA" in data.columns:
-            check_beta_column(data, effect_column, preprocessing)
+        if "BETA" in data.columns and preprocessing in ['Fill', 'Fill_delete']:
+            check_beta_column(data, effect_column)
             self.checks["BETA"] = True
 
         # Ensure P column contains valid values
@@ -269,6 +268,12 @@ class Geno:
         if preprocessing in ['Fill', 'Fill_delete']:
             fill_se_p(data)
 
+        # Compute or fill the FSTAT column
+        # Under normal preprocessing: compute/create/fill FSTAT
+        # If preprocessing == "None": only compute FSTAT when fill_f=True
+        if preprocessing in ['Fill', 'Fill_delete'] or fill_f:
+            fill_fstatistic(data, overwrite=fill_f)
+
         # Process allele columns
         for allele_col in ["EA", "NEA"]:
             check_allele_condition = (allele_col in data.columns) and (
@@ -590,7 +595,7 @@ class Geno:
         if not self.checks.get("EA"):
             check_allele_column(data_prs, "EA", keep_indel=False)
         if not self.checks.get("BETA"):
-            check_beta_column(data_prs, effect_column=None, preprocessing='Fill_delete')
+            check_beta_column(data_prs, effect_column=None)
 
         initial_rows = data_prs.shape[0]
         data_prs.dropna(subset=["SNP", "EA", "BETA"], inplace=True)
@@ -740,8 +745,8 @@ class Geno:
                                           to make results more interpretable. Default is True.
 
         Returns:
-            None: Updates the BETA, SE, and P columns of the data attribute based on the results
-                  of the association tests.
+            None: Updates the BETA, SE, P, and FSTAT columns of the data attribute based on the 
+                  results of the association tests.
 
         Note:
             This method requires the phenotype to be set using the set_phenotype() function.
@@ -796,6 +801,9 @@ class Geno:
         if n_updated < n_original:
             print(f"{n_original - n_updated}({(n_original - n_updated)/n_original*100:.3f}%) SNPs have been removed.")
 
+        # Recompute FSTAT to be consistent with the updated BETA/SE/P values
+        fill_fstatistic(updated_data, overwrite=True)
+
         # Update the instance data
         self.data = updated_data
         return
